


#include <glib-object.h>

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/extensions/contact_sheet/gth-contact-sheet-theme.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/extensions/contact_sheet/gth-contact-sheet-theme.h"
GType
gth_contact_sheet_background_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_CONTACT_SHEET_BACKGROUND_TYPE_SOLID, "GTH_CONTACT_SHEET_BACKGROUND_TYPE_SOLID", "solid" },
      { GTH_CONTACT_SHEET_BACKGROUND_TYPE_VERTICAL, "GTH_CONTACT_SHEET_BACKGROUND_TYPE_VERTICAL", "vertical" },
      { GTH_CONTACT_SHEET_BACKGROUND_TYPE_HORIZONTAL, "GTH_CONTACT_SHEET_BACKGROUND_TYPE_HORIZONTAL", "horizontal" },
      { GTH_CONTACT_SHEET_BACKGROUND_TYPE_FULL, "GTH_CONTACT_SHEET_BACKGROUND_TYPE_FULL", "full" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthContactSheetBackgroundType", values);
  }
  return etype;
}
GType
gth_contact_sheet_frame_style_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_CONTACT_SHEET_FRAME_STYLE_NONE, "GTH_CONTACT_SHEET_FRAME_STYLE_NONE", "none" },
      { GTH_CONTACT_SHEET_FRAME_STYLE_SIMPLE, "GTH_CONTACT_SHEET_FRAME_STYLE_SIMPLE", "simple" },
      { GTH_CONTACT_SHEET_FRAME_STYLE_SIMPLE_WITH_SHADOW, "GTH_CONTACT_SHEET_FRAME_STYLE_SIMPLE_WITH_SHADOW", "simple-with-shadow" },
      { GTH_CONTACT_SHEET_FRAME_STYLE_SHADOW, "GTH_CONTACT_SHEET_FRAME_STYLE_SHADOW", "shadow" },
      { GTH_CONTACT_SHEET_FRAME_STYLE_SLIDE, "GTH_CONTACT_SHEET_FRAME_STYLE_SLIDE", "slide" },
      { GTH_CONTACT_SHEET_FRAME_STYLE_SHADOW_IN, "GTH_CONTACT_SHEET_FRAME_STYLE_SHADOW_IN", "shadow-in" },
      { GTH_CONTACT_SHEET_FRAME_STYLE_SHADOW_OUT, "GTH_CONTACT_SHEET_FRAME_STYLE_SHADOW_OUT", "shadow-out" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthContactSheetFrameStyle", values);
  }
  return etype;
}



